]> git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - client.h
Merge branch 'master' into Mario/wrath-darkplaces_extra
[xonotic/darkplaces.git] / client.h
index 67262d7c2990c2f3073497525b28b351e41dcf17..f286e208b07e03b7ee7ae140bdbf365396566393 100644 (file)
--- a/client.h
+++ b/client.h
@@ -577,7 +577,7 @@ typedef struct client_static_s
        int demonum;
        // list of demos in loop
        char demos[MAX_DEMOS][MAX_DEMONAME];
// the actively playing demo (set by CL_PlayDemo_f)
        char demoname[MAX_QPATH];
 
 // demo recording info must be here, because record is started before
@@ -848,6 +848,7 @@ typedef struct client_state_s
        qbool oldonground;
        double lastongroundtime;
        double hitgroundtime;
+       double bobongroundtime;
        float bob2_smooth;
        float bobfall_speed;
        float bobfall_swing;
@@ -870,7 +871,12 @@ typedef struct client_state_s
        // how long it has been since the previous client frame in real time
        // (not game time, for that use cl.time - cl.oldtime)
        double realframetime;
-       
+
+       // used by cl_nettimesyncboundmode 7
+#define NUM_TS_ERRORS 32 // max 256
+       unsigned char ts_error_num;
+       float ts_error_stor[NUM_TS_ERRORS];
+
        // fade var for fading while dead
        float deathfade;
 
@@ -1294,6 +1300,7 @@ void CL_WriteDemoMessage(sizebuf_t *mesage);
 void CL_CutDemo(unsigned char **buf, fs_offset_t *filesize);
 void CL_PasteDemo(unsigned char **buf, fs_offset_t *filesize);
 
+void CL_PlayDemo(const char *demo);
 void CL_NextDemo(void);
 void CL_Stop_f(cmd_state_t *cmd);
 void CL_Record_f(cmd_state_t *cmd);
@@ -577,7 +577,7 @@ typedef struct client_static_s
        // list of demos in loop
        char demos[MAX_DEMOS][MAX_DEMONAME];
-       // the actively playing demo (set by CL_PlayDemo_f)
+       // the actively playing demo (set by CL_PlayDemo)
        char demoname[MAX_QPATH];
 